@@ -15,6 +15,7 @@ from rdfhelpers.templated import Templated, Composable
 from rdfhelpers.constructor import Constructor
 from rdfhelpers.labels import LabelCache, SKOSLabelCache, BNodeTracker, BNodeMarker
 from rdfhelpers.gsp import GraphStoreClient
+from rdfhelpers.tinyrml import RR, Mapper
 
 __all__ = [
     'expandQName', 'URI', 'getvalue', 'setvalue',
@@ -26,5 +27,6 @@ __all__ = [
     'Templated', 'Composable',
     'Constructor',
     'LabelCache', 'SKOSLabelCache', 'BNodeTracker', 'BNodeMarker',
-    'GraphStoreClient'
+    'GraphStoreClient',
+    'RR', 'Mapper'
 ]
